@@ -1,5 +1,5 @@
 package NetHack::Item::Other;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Moose;
 extends 'NetHack::Item';
@@ -12,18 +12,9 @@ has is_chained_to_you => (
     isa    => 'Bool',
 );
 
-after incorporate_stats => sub {
-    my $self  = shift;
-    my $stats = shift;
-
-    $self->is_chained_to_you($stats->{chained});
-};
-
-after incorporate_stats_from => sub {
-    my $self  = shift;
-    my $other = shift;
-
-    $self->incorporate_stat($other => 'is_chained_to_you');
+with 'NetHack::Item::Role::IncorporatesStats' => {
+    attribute => 'is_chained_to_you',
+    stat      => 'chained',
 };
 
 __PACKAGE__->meta->install_spoilers(qw/monster/);
