@@ -1,5 +1,5 @@
 package NetHack::Item::Ring;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Moose;
 extends 'NetHack::Item';
@@ -20,20 +20,10 @@ has hand => (
     isa     => 'NetHack::Item::Hand',
 );
 
-after incorporate_stats => sub {
-    my $self  = shift;
-    my $stats = shift;
-
-    if (($stats->{worn} || '') =~ /(left|right)/) {
-        $self->hand($1);
-    }
-};
-
-after incorporate_stats_from => sub {
-    my $self  = shift;
-    my $other = shift;
-
-    $self->incorporate_stat($other => 'hand');
+with 'NetHack::Item::Role::IncorporatesStats' => {
+    attribute      => 'hand',
+    stat           => 'worn',
+    stat_predicate => sub { /(left|right)/ ? $1 : undef },
 };
 
 around hand => sub {
