@@ -1,5 +1,5 @@
 package NetHack::Item::Role::Enchantable;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Moose::Role;
 
@@ -9,19 +9,9 @@ has enchantment => (
     predicate => 'enchantment_known',
 );
 
-after incorporate_stats => sub {
-    my $self  = shift;
-    my $stats = shift;
-
-    $self->enchantment($stats->{enchantment})
-        if defined $stats->{enchantment};
-};
-
-after incorporate_stats_from => sub {
-    my $self  = shift;
-    my $other = shift;
-
-    $self->incorporate_stat($other => 'enchantment');
+with 'NetHack::Item::Role::IncorporatesStats' => {
+    attribute    => 'enchantment',
+    defined_stat => 1,
 };
 
 sub numeric_enchantment {
