@@ -1,5 +1,5 @@
 package NetHack::Item::Tool::Candelabrum;
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Moose;
 extends 'NetHack::Item::Tool::Light';
@@ -12,18 +12,9 @@ has candles_attached => (
     default => 0,
 );
 
-after incorporate_stats => sub {
-    my $self  = shift;
-    my $stats = shift;
-
-    $self->candles_attached($stats->{candles});
-};
-
-after incorporate_stats_from => sub {
-    my $self  = shift;
-    my $other = shift;
-
-    $self->incorporate_stat($other => 'candles_attached');
+with 'NetHack::Item::Role::IncorporatesStats' => {
+    attribute => 'candles_attached',
+    stat      => 'candles',
 };
 
 __PACKAGE__->meta->make_immutable;
